package com.temboo.Library.Amazon.IAM;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
EnableMFADevice

Enables the specified MFA device and associates it with the specified user name. When enabled, the MFA device is required for every subsequent login by the user name associated with the device.
*/
public class EnableMFADevice extends Choreography {

	/**
	Create a new instance of the EnableMFADevice Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public EnableMFADevice(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/IAM/EnableMFADevice"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return EnableMFADeviceInputSet
	*/
	public EnableMFADeviceInputSet newInputSet() {
		return new EnableMFADeviceInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public EnableMFADeviceResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new EnableMFADeviceResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the EnableMFADevice
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class EnableMFADeviceInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}


		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}


		/** 
		Set the value of the AuthenticationCode1 input for this Choreo. 

		@param String - (required, string) An authentication code emitted by the device.
		*/
		public void set_AuthenticationCode1(String value) {
			this.setInput("AuthenticationCode1", value);
		}


		/** 
		Set the value of the AuthenticationCode2 input for this Choreo. 

		@param String - (required, string) A subsequent authentication code emitted by the device.
		*/
		public void set_AuthenticationCode2(String value) {
			this.setInput("AuthenticationCode2", value);
		}


		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}


		/** 
		Set the value of the SerialNumber input for this Choreo. 

		@param String - (required, string) The serial number that uniquely identifies the MFA device. For virtual MFA devices, the serial number is the same as the ARN.
		*/
		public void set_SerialNumber(String value) {
			this.setInput("SerialNumber", value);
		}


		/** 
		Set the value of the UserName input for this Choreo. 

		@param String - (required, string) Name of the user for whom you want to enable the MFA device.
		*/
		public void set_UserName(String value) {
			this.setInput("UserName", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the EnableMFADevice Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class EnableMFADeviceResultSet extends ResultSet {
		public EnableMFADeviceResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
