package com.temboo.Library.Fitbit.Activities;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdateActivityDailyGoals

Create or updates a user's daily activity goals.
*/
public class UpdateActivityDailyGoals extends Choreography {

	/**
	Create a new instance of the UpdateActivityDailyGoals Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdateActivityDailyGoals(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Fitbit/Activities/UpdateActivityDailyGoals"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdateActivityDailyGoalsInputSet
	*/
	public UpdateActivityDailyGoalsInputSet newInputSet() {
		return new UpdateActivityDailyGoalsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdateActivityDailyGoalsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdateActivityDailyGoalsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdateActivityDailyGoals
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdateActivityDailyGoalsInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}


		/** 
		Set the value of the ActiveMinutes input for this Choreo. 

		@param Integer - (conditional, integer) The number of minutes to remain active for a daily activity goal.
		*/
		public void set_ActiveMinutes(Integer value) {
			this.setInput("ActiveMinutes", value);
		}

		/** 
		Set the value of the ActiveMinutes input for this Choreo as a String. 

		@param String - (conditional, integer) The number of minutes to remain active for a daily activity goal.
		*/
		public void set_ActiveMinutes(String value) {
			this.setInput("ActiveMinutes", value);	
		}
		/** 
		Set the value of the CaloriesOut input for this Choreo. 

		@param Integer - (conditional, integer) The daily calorie burn goal.
		*/
		public void set_CaloriesOut(Integer value) {
			this.setInput("CaloriesOut", value);
		}

		/** 
		Set the value of the CaloriesOut input for this Choreo as a String. 

		@param String - (conditional, integer) The daily calorie burn goal.
		*/
		public void set_CaloriesOut(String value) {
			this.setInput("CaloriesOut", value);	
		}
		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Fitbit.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}


		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Fitbit.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}


		/** 
		Set the value of the Distance input for this Choreo. 

		@param BigDecimal - (conditional, decimal) The desired distance for a daily activity goal.
		*/
		public void set_Distance(BigDecimal value) {
			this.setInput("Distance", value);
		}

		/** 
		Set the value of the Distance input for this Choreo as a String. 

		@param String - (conditional, decimal) The desired distance for a daily activity goal.
		*/
		public void set_Distance(String value) {
			this.setInput("Distance", value);	
		}
		/** 
		Set the value of the Floors input for this Choreo. 

		@param Integer - (conditional, integer) The number of floors walked for a daily activity goal.
		*/
		public void set_Floors(Integer value) {
			this.setInput("Floors", value);
		}

		/** 
		Set the value of the Floors input for this Choreo as a String. 

		@param String - (conditional, integer) The number of floors walked for a daily activity goal.
		*/
		public void set_Floors(String value) {
			this.setInput("Floors", value);	
		}
		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that you want the response to be in: xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}


		/** 
		Set the value of the Steps input for this Choreo. 

		@param Integer - (conditional, integer) The number of steps to take for a daily activity goal.
		*/
		public void set_Steps(Integer value) {
			this.setInput("Steps", value);
		}

		/** 
		Set the value of the Steps input for this Choreo as a String. 

		@param String - (conditional, integer) The number of steps to take for a daily activity goal.
		*/
		public void set_Steps(String value) {
			this.setInput("Steps", value);	
		}
		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) The user's encoded id. Defaults to "-" (dash) which will return data for the user associated with the token credentials provided.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdateActivityDailyGoals Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdateActivityDailyGoalsResultSet extends ResultSet {
		public UpdateActivityDailyGoalsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Fitbit.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
