package com.temboo.Library.Instagram;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RecentlyTaggedMedia

Retrieves a list of recently tagged media.
*/
public class RecentlyTaggedMedia extends Choreography {

	/**
	Create a new instance of the RecentlyTaggedMedia Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RecentlyTaggedMedia(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Instagram/RecentlyTaggedMedia"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RecentlyTaggedMediaInputSet
	*/
	public RecentlyTaggedMediaInputSet newInputSet() {
		return new RecentlyTaggedMediaInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RecentlyTaggedMediaResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RecentlyTaggedMediaResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RecentlyTaggedMedia
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RecentlyTaggedMediaInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (conditional, string) The access token retrieved during the OAuth 2.0 process. Required unless you provide the ClientID.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Instagram after registering your application. Required unless you provide the AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}


		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) The number of results to return.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) The number of results to return.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}
		/** 
		Set the value of the MaxID input for this Choreo. 

		@param Integer - (optional, integer) Returns media tagged earlier than this max_tag_id. Used to paginate through results.
		*/
		public void set_MaxID(Integer value) {
			this.setInput("MaxID", value);
		}

		/** 
		Set the value of the MaxID input for this Choreo as a String. 

		@param String - (optional, integer) Returns media tagged earlier than this max_tag_id. Used to paginate through results.
		*/
		public void set_MaxID(String value) {
			this.setInput("MaxID", value);	
		}
		/** 
		Set the value of the MinID input for this Choreo. 

		@param Integer - (optional, integer) Returns media tagged later than this max_tag_id. Used to paginate through results.
		*/
		public void set_MinID(Integer value) {
			this.setInput("MinID", value);
		}

		/** 
		Set the value of the MinID input for this Choreo as a String. 

		@param String - (optional, integer) Returns media tagged later than this max_tag_id. Used to paginate through results.
		*/
		public void set_MinID(String value) {
			this.setInput("MinID", value);	
		}
		/** 
		Set the value of the TagName input for this Choreo. 

		@param String - (required, string) Enter a valid tag identifier, such as: nofliter
		*/
		public void set_TagName(String value) {
			this.setInput("TagName", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RecentlyTaggedMedia Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RecentlyTaggedMediaResultSet extends ResultSet {
		public RecentlyTaggedMediaResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Instagram.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
