package com.temboo.Library.Withings.Notification;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Subscribe

Allows your application to subscribe users to notifications. 
*/
public class Subscribe extends Choreography {

	/**
	Create a new instance of the Subscribe Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Subscribe(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Withings/Notification/Subscribe"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SubscribeInputSet
	*/
	public SubscribeInputSet newInputSet() {
		return new SubscribeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SubscribeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SubscribeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Subscribe
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SubscribeInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}


		/** 
		Set the value of the Application input for this Choreo. 

		@param Integer - (optional, integer) Specifies the device type for which the notification is to be activated. Set to 1 for Bodyscale.
		*/
		public void set_Application(Integer value) {
			this.setInput("Application", value);
		}

		/** 
		Set the value of the Application input for this Choreo as a String. 

		@param String - (optional, integer) Specifies the device type for which the notification is to be activated. Set to 1 for Bodyscale.
		*/
		public void set_Application(String value) {
			this.setInput("Application", value);	
		}
		/** 
		Set the value of the CallbackURL input for this Choreo. 

		@param String - (required, string) The URL the API notification will be pushed to.
		*/
		public void set_CallbackURL(String value) {
			this.setInput("CallbackURL", value);
		}


		/** 
		Set the value of the Comment input for this Choreo. 

		@param String - (optional, string) A comment string used for a description to display to the user when presenting them with your notification setup.
		*/
		public void set_Comment(String value) {
			this.setInput("Comment", value);
		}


		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The Consumer Key provided by Withings.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}


		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The Consumer Secret provided by Withings.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}


		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (required, string) The ID of the user to setup a subscription for.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Subscribe Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SubscribeResultSet extends ResultSet {
		public SubscribeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Withings.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
