package com.temboo.Library.Wordnik.Word;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetFrequency

Retrieves the word frequency of a given word.
*/
public class GetFrequency extends Choreography {

	/**
	Create a new instance of the GetFrequency Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetFrequency(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Wordnik/Word/GetFrequency"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetFrequencyInputSet
	*/
	public GetFrequencyInputSet newInputSet() {
		return new GetFrequencyInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetFrequencyResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetFrequencyResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetFrequency
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetFrequencyInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key from Wordnik.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}


		/** 
		Set the value of the Cannonical input for this Choreo. 

		@param String - (optional, string) Deprecated (retained for backward compatibility only).
		*/
		public void set_Cannonical(String value) {
			this.setInput("Cannonical", value);
		}


		/** 
		Set the value of the EndYear input for this Choreo. 

		@param Integer - (optional, integer) End year for which to return word use frequencies. Defaults to 2012.
		*/
		public void set_EndYear(Integer value) {
			this.setInput("EndYear", value);
		}

		/** 
		Set the value of the EndYear input for this Choreo as a String. 

		@param String - (optional, integer) End year for which to return word use frequencies. Defaults to 2012.
		*/
		public void set_EndYear(String value) {
			this.setInput("EndYear", value);	
		}
		/** 
		Set the value of the ResponseType input for this Choreo. 

		@param String - (optional, string) Response can be either JSON or XML. Defaults to JSON.
		*/
		public void set_ResponseType(String value) {
			this.setInput("ResponseType", value);
		}


		/** 
		Set the value of the StartYear input for this Choreo. 

		@param Integer - (optional, integer) Start year for which to return word use frequencies. Defaults to 1800.
		*/
		public void set_StartYear(Integer value) {
			this.setInput("StartYear", value);
		}

		/** 
		Set the value of the StartYear input for this Choreo as a String. 

		@param String - (optional, integer) Start year for which to return word use frequencies. Defaults to 1800.
		*/
		public void set_StartYear(String value) {
			this.setInput("StartYear", value);	
		}
		/** 
		Set the value of the UseCanonical input for this Choreo. 

		@param Boolean - (optional, boolean) If true will try to return the correct word root ('cats' -> 'cat'). If false returns exactly what was requested. Defaults to false.
		*/
		public void set_UseCanonical(Boolean value) {
			this.setInput("UseCanonical", value);
		}

		/** 
		Set the value of the UseCanonical input for this Choreo as a String. 

		@param String - (optional, boolean) If true will try to return the correct word root ('cats' -> 'cat'). If false returns exactly what was requested. Defaults to false.
		*/
		public void set_UseCanonical(String value) {
			this.setInput("UseCanonical", value);	
		}
		/** 
		Set the value of the Word input for this Choreo. 

		@param String - (required, string) The word you want to look up on Wordnik.
		*/
		public void set_Word(String value) {
			this.setInput("Word", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetFrequency Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetFrequencyResultSet extends ResultSet {
		public GetFrequencyResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Wordnik.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
